from django import template
from django.templatetags.static import static
from django.utils import formats
from django.utils.safestring import mark_safe

register = template.Library()


@register.filter
def value(val, pm=False, r=2):
    if val is None:
        return ""
    _prefix = ""
    _suffix = "&nbsp;€"
    _val = formats.number_format(val, decimal_pos=r, use_l10n=True, force_grouping=True)

    if val > 0:
        if pm:
            _prefix += "&plus;&nbsp;"
    elif val < 0:
        _val = _val[1:]
        _prefix += "&minus;&nbsp;"

    return mark_safe(f"{_prefix}{_val}{_suffix}")


@register.filter
def pmvalue(val):
    return value(val, True)


@register.filter
def pmrvalue(val):
    return value(val, True, r=0)


@register.filter
def remix(icon, *args):
    return remixnl(f"{icon}-line", *args)


@register.filter
def remixnl(icon, cls=""):
    return mark_safe(f"""<span class="ri-{icon} {cls}"></span>""")


@register.filter
def messageicon(level):
    ico = {
        10: "bug",
        20: "information",
        25: "check",
        30: "alert",
        40: "error-warning",
    }

    return remix(ico.get(level, "question"))


@register.filter
def extension(file):
    return file.name.split(".")[-1].upper()


@register.filter
def verbose_name(obj):
    return obj._meta.verbose_name


@register.filter
def adding(obj):
    return obj._state.adding


@register.simple_tag
def css(href):
    return mark_safe(
        f"""<link rel="stylesheet" href="{static(href)}" type="text/css">"""
    )


@register.simple_tag
def js(href):
    return mark_safe(f"""<script src="{static(href)}" defer></script>""")


@register.filter
def balance(accounts):
    return sum(
        statement.value for acc in accounts if (statement := acc.statement_set.first())
    )
